# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Buffer = object
DISPLAY_TEXT = ''
HELP_TEXT = ''
NAVKEYS = tuple()
PRINT_UPDATE_MAX_TIME = 0
PseudoFileErr = object
PseudoFileIn = object
PseudoFileOut = object
Shell = object
ShellFacade = object
ShellFrame = object
VERSION = ''
cd = dummy_function
cmp_to_key = dummy_function
ls = dummy_function
magic = dummy_function
pwd = dummy_function
sx = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EditStartupScriptDialog = object
Frame = object
ID_ABOUT = object
ID_AUTOCOMP_DOUBLE = object
ID_AUTOCOMP_MAGIC = object
ID_AUTOCOMP_SHOW = object
ID_AUTOCOMP_SINGLE = object
ID_AUTO_SAVESETTINGS = object
ID_CALLTIPS_INSERT = object
ID_CALLTIPS_SHOW = object
ID_CLEAR = object
ID_CLEARHISTORY = object
ID_CLOSE = object
ID_COPY = object
ID_COPY_PLUS = object
ID_CUT = object
ID_DELSETTINGSFILE = object
ID_EDITSTARTUPSCRIPT = object
ID_EMPTYBUFFER = object
ID_ENABLEAUTOSYMPY = object
ID_ENABLESHELLMODE = object
ID_EXECSTARTUPSCRIPT = object
ID_EXIT = object
ID_FIND = object
ID_FINDNEXT = object
ID_FINDPREVIOUS = object
ID_HELP = object
ID_HIDEFOLDINGMARGIN = object
ID_NAMESPACE = object
ID_NEW = object
ID_OPEN = object
ID_PASTE = object
ID_PASTE_PLUS = object
ID_PRINT = object
ID_REDO = object
ID_REVERT = object
ID_SAVE = object
ID_SAVEACOPY = object
ID_SAVEAS = object
ID_SAVEHISTORY = object
ID_SAVEHISTORYNOW = object
ID_SAVESETTINGS = object
ID_SELECTALL = object
ID_SHOWPYSLICESTUTORIAL = object
ID_SHOWTOOLS = object
ID_SHOW_LINENUMBERS = object
ID_TOGGLE_MAXIMIZE = object
ID_UNDO = object
ID_WRAP = object
ShellFrameMixin = object
VERSION = ''



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


PseudoFile = object
PseudoFileErr = object
PseudoFileIn = object
PseudoFileOut = object
PseudoKeyword = object



#!/usr/bin/env python
# This file is managed by `git_helper`. Don't edit it directly
"""Setup script"""

from __pkginfo__ import *

from setuptools import setup, find_packages

setup(
		author=author,
		author_email=author_email,
		classifiers=classifiers,
		description=short_desc,
		entry_points=entry_points,
		extras_require=extras_require,
		include_package_data=True,
		install_requires=install_requires,
		license=__license__,
		long_description=long_description,
		name=pypi_name,
		packages=find_packages(exclude=("tests", "doc-source")),
		project_urls=project_urls,
		py_modules=py_modules,
		python_requires=">=3.6",
		url=web,
		version=__version__,
		keywords=keywords,

		)



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


BytesIO = object
getAllAttributeNames = dummy_function
getAttributeNames = dummy_function
getAutoCompleteList = dummy_function
getBaseObject = dummy_function
getCallTip = dummy_function
getConstructor = dummy_function
getRoot = dummy_function
getTokens = dummy_function
hasattrAlwaysReturnsTrue = dummy_function
rtrimTerminus = dummy_function
string_types = tuple()
